FROM python:3.13-alpine AS builder

RUN apk add --no-cache curl && \
    curl -sSL https://install.python-poetry.org | python3 -

ENV PATH="/root/.local/bin:$PATH" \
    POETRY_NO_INTERACTION=1 \
    POETRY_VIRTUALENVS_IN_PROJECT=1 \
    POETRY_VIRTUALENVS_CREATE=1 \
    POETRY_CACHE_DIR=/var/cache/pypoetry

WORKDIR /app
COPY pyproject.toml poetry.lock ./
RUN poetry install --only main && \
    rm -rf ${POETRY_CACHE_DIR}

FROM python:3.13-alpine AS runtime

RUN apk add --no-cache libmagic

ENV REDIS_URL=redis://redis:6379/0

COPY --from=builder /app/.venv /app/.venv
COPY ./src/auto_transcoder /app/auto_transcoder

WORKDIR /app
EXPOSE 5000

ENTRYPOINT ["/app/.venv/bin/python", "-m", "auto_transcoder.server"]
